==> ioc-liturgical-react-1.0.3.tgz: package/es/modules/ModalNewEntryForm.js <==
var _class, _temp, _initialiseProps, _ModalNewEntryForm$pr;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Button, ControlLabel, Modal, Well } from 'react-bootstrap';

import NewEntryForm from './NewEntryForm';
import MessageIcons from '../helpers/MessageIcons';

/**
 * Display modal content.
 */
export var ModalNewEntryForm = (_temp = _class = function (_React$Component) {
  _inherits(ModalNewEntryForm, _React$Component);

  function ModalNewEntryForm(props) {
    _classCallCheck(this, ModalNewEntryForm);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      showModal: true
    };

    _this.handleClose = _this.handleClose.bind(_this);
    _this.setMessage = _this.setMessage.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    return _this;
  }

  ModalNewEntryForm.prototype.setMessage = function setMessage(message) {
    this.setState({
      message: message
    });
  };

  ModalNewEntryForm.prototype.render = function render() {
    return React.createElement(
      'div',
      null,
      React.createElement(
        Modal,
        {
          backdrop: "static",
          dialogClassName: 'App-Modal-New-Entry-Form',
          show: this.state.showModal,
          onHide: this.handleClose,
          keyboard: true
        },
        React.createElement(
          Modal.Header,
          { closeButton: true },
          React.createElement(
            Modal.Title,
            null,
            this.props.title
          ),
          this.props.fromText && this.props.fromTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.fromTitle
          ),
          this.props.fromText && this.props.fromId && React.createElement(
            Well,
            { className: "App-Well-From-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.fromText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.fromId,
                ')'
              )
            )
          ),
          this.props.fromText && this.props.toText && this.props.toTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.toTitle
          ),
          this.props.toText && this.props.toId && React.createElement(
            Well,
            { className: "App-Well-To-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.toText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.toId,
                ')'
              )
            )
          ),
          this.props.toText && React.createElement(
            ControlLabel,
            null,
            this.state.labels.references.infoBelow
          )
        ),
        React.createElement(
          Modal.Body,
          null,
          React.createElement(NewEntryForm, {
            session: this.props.session,
            path: this.props.restPath,
            schema: this.props.schema,
            uiSchema: this.props.uiSchema,
            formData: this.props.formData,
            onSubmit: this.onSubmit
          })
        ),
        React.createElement(
          Modal.Footer,
          null,
          React.createElement(
            Button,
            { onClick: this.handleClose },
            this.state.labels.buttons.close
          )
        )
      )
    );
  };

  return ModalNewEntryForm;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this2.setState({
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      }
    });
  };

  this.onSubmit = function (_ref) {
    var formData = _ref.formData;

    if (_this2.props.onSubmit) {
      _this2.props.onSubmit(formData);
    }
  };

  this.handleClose = function () {
    _this2.setState({ showModal: false });
    if (_this2.props.onClose) {
      _this2.props.onClose(_this2.state.formData);
    }
  };
}, _temp);

process.env.NODE_ENV !== "production" ? ModalNewEntryForm.propTypes = (_ModalNewEntryForm$pr = {
  session: PropTypes.object.isRequired,
  restPath: PropTypes.string.isRequired,
  schema: PropTypes.object.isRequired,
  uiSchema: PropTypes.object.isRequired,
  formData: PropTypes.object.isRequired,
  title: PropTypes.string.isRequired
}, _ModalNewEntryForm$pr['title'] = PropTypes.string.isRequired, _ModalNewEntryForm$pr.fromTitle = PropTypes.string, _ModalNewEntryForm$pr.fromId = PropTypes.string, _ModalNewEntryForm$pr.fromText = PropTypes.string, _ModalNewEntryForm$pr.toTitle = PropTypes.string, _ModalNewEntryForm$pr.toId = PropTypes.string, _ModalNewEntryForm$pr.toText = PropTypes.string, _ModalNewEntryForm$pr.onSubmit = PropTypes.func, _ModalNewEntryForm$pr.onClose = PropTypes.func, _ModalNewEntryForm$pr) : void 0;
ModalNewEntryForm.defaultProps = {
  canUpdate: true
};

export default ModalNewEntryForm;

==> ioc-liturgical-react-1.0.6.tgz: package/es/modules/ModalNewEntryForm.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Button, ControlLabel, Modal, Well } from 'react-bootstrap';

import NewEntryForm from './NewEntryForm';
import MessageIcons from '../helpers/MessageIcons';

/**
 * Display modal content.
 */
export var ModalNewEntryForm = (_temp = _class = function (_React$Component) {
  _inherits(ModalNewEntryForm, _React$Component);

  function ModalNewEntryForm(props) {
    _classCallCheck(this, ModalNewEntryForm);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      showModal: true
    };

    _this.handleClose = _this.handleClose.bind(_this);
    _this.setMessage = _this.setMessage.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    return _this;
  }

  ModalNewEntryForm.prototype.setMessage = function setMessage(message) {
    this.setState({
      message: message
    });
  };

  ModalNewEntryForm.prototype.render = function render() {
    return React.createElement(
      'div',
      null,
      React.createElement(
        Modal,
        {
          backdrop: "static",
          dialogClassName: 'App-Modal-New-Entry-Form',
          show: this.state.showModal,
          onHide: this.handleClose,
          keyboard: true
        },
        React.createElement(
          Modal.Header,
          { closeButton: true },
          React.createElement(
            Modal.Title,
            null,
            this.props.title
          ),
          this.props.fromText && this.props.fromTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.fromTitle
          ),
          this.props.fromText && this.props.fromId && React.createElement(
            Well,
            { className: "App-Well-From-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.fromText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.fromId,
                ')'
              )
            )
          ),
          this.props.fromText && this.props.toText && this.props.toTitle && React.createElement(
            'div',
            { className: "App-Text-Refers-To" },
            this.props.toTitle
          ),
          this.props.toText && this.props.toId && React.createElement(
            Well,
            { className: "App-Well-To-Text" },
            React.createElement(
              'div',
              { className: "App-Modal-Text" },
              this.props.toText,
              React.createElement(
                'span',
                { className: "control-label" },
                ' (',
                this.props.toId,
                ')'
              )
            )
          ),
          this.props.toText && React.createElement(
            ControlLabel,
            null,
            this.state.labels.references.infoBelow
          )
        ),
        React.createElement(
          Modal.Body,
          null,
          React.createElement(NewEntryForm, {
            session: this.props.session,
            path: this.props.restPath,
            schema: this.props.schema,
            uiSchema: this.props.uiSchema,
            formData: this.props.formData,
            onSubmit: this.onSubmit
          })
        ),
        React.createElement(
          Modal.Footer,
          null,
          React.createElement(
            Button,
            { onClick: this.handleClose },
            this.state.labels.buttons.close
          )
        )
      )
    );
  };

  return ModalNewEntryForm;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;

    _this2.setState({
      labels: {
        buttons: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        references: labels[labelTopics.ViewReferences]
      }
    });
  };

  this.onSubmit = function (_ref) {
    var formData = _ref.formData;

    if (_this2.props.onSubmit) {
      _this2.props.onSubmit(formData);
    }
  };

  this.handleClose = function () {
    _this2.setState({ showModal: false });
    if (_this2.props.onClose) {
      _this2.props.onClose(_this2.state.formData);
    }
  };
}, _temp);

process.env.NODE_ENV !== "production" ? ModalNewEntryForm.propTypes = {
  session: PropTypes.object.isRequired,
  restPath: PropTypes.string.isRequired,
  schema: PropTypes.object.isRequired,
  uiSchema: PropTypes.object.isRequired,
  formData: PropTypes.object.isRequired,
  title: PropTypes.string.isRequired,
  fromTitle: PropTypes.string,
  fromId: PropTypes.string,
  fromText: PropTypes.string,
  toTitle: PropTypes.string,
  toId: PropTypes.string,
  toText: PropTypes.string,
  onSubmit: PropTypes.func,
  onClose: PropTypes.func
} : void 0;
ModalNewEntryForm.defaultProps = {
  canUpdate: true
};

export default ModalNewEntryForm;
